@@ -25,6 +25,9 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <liboil/liboil.h>
@@ -34,6 +37,8 @@
 
 #include <liboil/liboilprototype.h>
 
+static char * xstrdup (const char *s);
+
 void print_header (void);
 void print_footer (void);
 
@@ -59,7 +64,7 @@ int main (int argc, char *argv[])
         string = oil_prototype_to_string (proto);
         if (strlen (string) == 0) {
           free (string);
-          string = strdup("void");
+          string = xstrdup("void");
         }
 
         printf ("extern OilFunctionClass *oil_function_class_ptr_%s;\n",
@@ -134,3 +139,17 @@ void print_footer (void)
   printf ("\n");
 }
 
+static char *
+xstrdup (const char *s)
+{
+  int n = strlen(s);
+  char *t;
+
+  n = strlen(s);
+  t = malloc(n + 1);
+  memcpy (t, s, n);
+  t[n] = 0;
+
+  return t;
+}
+
