@@ -444,7 +444,7 @@ test_cpuid (void *ignored)
   get_cpuid (0x00000000, &eax, &ebx, &ecx, &edx);
 }
 
-static int
+static void
 oil_cpu_detect_cpuid (void)
 {
   uint32_t eax, ebx, ecx, edx;
@@ -457,7 +457,7 @@ oil_cpu_detect_cpuid (void)
   oil_cpu_fault_check_disable ();
   if (!ret) {
     /* CPU thinks cpuid is an illegal instruction. */
-    return 0;
+    return;
   }
 
   get_cpuid (0x00000000, &level, (uint32_t *)(vendor+0),
@@ -466,7 +466,7 @@ oil_cpu_detect_cpuid (void)
   OIL_DEBUG("cpuid %d %s", level, vendor);
 
   if (level < 1) {
-    return 0;
+    return;
   }
 
   get_cpuid (0x00000001, &eax, &ebx, &ecx, &edx);
@@ -509,13 +509,13 @@ oil_cpu_detect_cpuid (void)
 
     get_cpuid (0x80000005, &eax, &ebx, &ecx, &edx);
 
-    OIL_WARNING("L1 D-cache: %d kbytes, %d-way, %d lines/tag, %d line size\n",
+    OIL_INFO("L1 D-cache: %d kbytes, %d-way, %d lines/tag, %d line size",
         (ecx>>24)&0xff, (ecx>>16)&0xff, (ecx>>8)&0xff, ecx&0xff);
-    OIL_WARNING("L1 I-cache: %d kbytes, %d-way, %d lines/tag, %d line size\n",
+    OIL_INFO("L1 I-cache: %d kbytes, %d-way, %d lines/tag, %d line size",
         (edx>>24)&0xff, (edx>>16)&0xff, (edx>>8)&0xff, edx&0xff);
 
     get_cpuid (0x80000006, &eax, &ebx, &ecx, &edx);
-    OIL_WARNING("L2 cache: %d kbytes, %d assoc, %d lines/tag, %d line size\n",
+    OIL_INFO("L2 cache: %d kbytes, %d assoc, %d lines/tag, %d line size",
         (ecx>>16)&0xffff, (ecx>>12)&0xf, (ecx>>8)&0xf, ecx&0xff);
   }
 }
@@ -542,7 +542,7 @@ oil_cpu_detect_kernel_support (void)
 		       OIL_IMPL_FLAG_MMXEXT | OIL_IMPL_FLAG_SSE3);
   }
 #endif
-#if !defined(__linux__) && !defined(__FreeBSD__)
+#if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__NetBSD__)
   /* If we don't know that the operating system supports SSE, don't trust that
    * it will properly support it.
    */
@@ -743,7 +743,7 @@ oil_cpu_detect_mips(void)
 static void
 oil_cpu_detect_arch(void)
 {
-#ifdef __i386__
+#if defined(__i386__) || defined(__amd64__)
   oil_cpu_detect_i386();
 #endif
 #if defined(__powerpc__) || defined(__PPC__) || defined(__ppc__)
